//
//  RxViewController.m
//  RxBrowser
//
//  Created by Ranorex Ranorex on 7/27/12.
//  Copyright (c) 2012 Ranorex. All rights reserved.
//

#import "RxViewController.h"

const NSString* RXBC_VERSION = @/*_iOsLibVersion_*/"1.7.0"/**/;

@interface RxViewController ()

@end

@implementation RxViewController

@synthesize backButton      = _backButton;
@synthesize forwardButton   = _forwardButton;
@synthesize refreshButton   = _refreshButton;
@synthesize webAddress      = _webAddress;
@synthesize webView         = _webView;
@synthesize goButton        = _goButton;
@synthesize debugButton     = _debugButton;
@synthesize loadingIndicator = _loadingIndicator;
@synthesize errorTextView = _errorTextView;

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    _webAddress.delegate = self;
    _webAddress.placeholder = [NSString stringWithFormat:@"RxBrowser v%@: Enter web address here...", RXBC_VERSION];
    _webView.delegate = self;
    _webView.accessibilityLabel = @"WebContent";
    _webAddress.clearButtonMode = UITextFieldViewModeAlways;
    [self updateControlStates];
    
    //[self initDefaultPage];
    [_webAddress becomeFirstResponder];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    
    // Release any retained subviews of the main view.
}

-(void)initDefaultPage
{
    NSURL *url = [NSURL URLWithString:@"http://ranorex.com"];
    NSURLRequest *urlRequest = [NSURLRequest requestWithURL:url];
    [_webView loadRequest:urlRequest];
    [_webAddress becomeFirstResponder];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return YES;
    //if ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPhone) {
    //    return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
    //} else {
    //    return YES;
    //}
}

//Actions
-(IBAction)onBack:(id)sender
{
    if(_webView.canGoBack)
    {
        [_webView goBack];
    }
    
    [self updateControlStates];
}

-(IBAction)onForward:(id)sender
{
    if(_webView.canGoForward)
    {
        [_webView goForward];
    }
    
    [self updateControlStates];
}

-(IBAction)onRefresh:(id)sender
{
    [_webView reload];
    [self updateControlStates];
}

-(IBAction)onWebAddressChanged:(id)sender
{
    [self updateControlStates];
}

-(IBAction)onDebug:(id)sender
{
}

-(IBAction)onGo:(id)sender
{
    NSAutoreleasePool* pool = [[NSAutoreleasePool alloc] init];
    NSString* urlString = _webAddress.text;
    
    [_webView performSelector:@selector(loadWebPageFromURL:) withObject:urlString];
    
    [self updateControlStates];
    [self.webAddress resignFirstResponder];
    [_webView resignFirstResponder];
    [pool drain];
}

-(void)updateControlStates
{
    _backButton.enabled         = _webView.canGoBack;
    _forwardButton.enabled      = _webView.canGoForward;
    _goButton.enabled           = [self validateUrl:_webAddress.text];
    _refreshButton.enabled      = _webView.request != nil && [self validateUrl:_webView.request.URL.absoluteString];
}

- (BOOL)validateUrl:(NSString *) candidate 
{
    if(candidate == nil || candidate.length <= 0)
    {
        return false;
    }
    
    return true;
}

//textviewdelegate
-(BOOL)textFieldShouldReturn:(UITextField *)textField
{
    [textField resignFirstResponder];
    [self onGo:self];
    return NO;
}

#pragma mark WebViewDelegate Implementation

-(void)webViewDidStartLoad:(UIWebView *)webView
{
    [self.loadingIndicator startAnimating];
}

-(void)webViewDidFinishLoad:(UIWebView *)webView
{
    [self.loadingIndicator stopAnimating];
    self.errorTextView.hidden = true;
    
    [self updateControlStates];
    if(_refreshButton.enabled)
    {
        _webAddress.text            = _webView.request.URL.absoluteString;
    }
}

-(void)webView:(UIWebView *)webView didFailLoadWithError:(NSError *)error
{
    [self.loadingIndicator stopAnimating];
    self.errorTextView.text = [error localizedDescription];
    self.errorTextView.hidden = false;
}

@end
